# import logging

from django import template
from django.conf import settings as user_settings

from sorl.thumbnail import get_thumbnail, delete

from django_easy_instagram import settings
from django_easy_instagram.scraper import get_posts

register = template.Library()


class InstagramUserRecentMediaNode(template.Node):

    def __init__(self, var_name):
        self.var_name = var_name
        self.username = template.Variable(var_name)

    def render(self, context):

        try:
            context['recent_media'] = get_posts(self.username.resolve(context))
        except template.base.VariableDoesNotExist:
            logger.warning(
                " variable name \"{}\" not found in context!"
                " Using a raw string as input is DEPRECATED."
                " Please use a template variable instead!".format(self.var_name)
            )

            context['recent_media'] = get_posts(username=self.var_name)

        return ''


@register.tag
def instagram_user_recent_media(parser, token):
    try:
        tagname, username = token.split_contents()

        return InstagramUserRecentMediaNode(username)
    except ValueError:
        raise template.TemplateSyntaxError(
            "%r tag requires a single argument" % token.contents.split()[0]
        )


@register.filter(name='local_cache')
def local_cache(value, size="600x600"):
    im = get_thumbnail(value, size, crop='center', quality=settings.INSTAGRAM_CACHE_QUALITY)
    return im.url



import json
import logging
import requests

from . import settings

def get_posts(username):

    try:
        ua = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/127.0.0.0 Safari/537.36'
        if hasattr(settings, 'INSTAGRAM_UA') and settings.INSTAGRAM_UA:
            ua = settings.INSTAGRAM_UA

        # URL of the Instagram Endpoint
        url = 'https://www.instagram.com/api/v1/users/web_profile_info/?username=farandride'

        headers = {
            'accept': '*/*',
            'accept-language': 'en',
            'cookie': 'csrftoken=dLUk2HS4UMoL4j5yHNORNw;',
            'priority': 'u=1, i',
            'referer': 'https://www.instagram.com/farandride/?hl=de',
            'user-agent': ua,
            'x-asbd-id': '129477',
            'x-csrftoken': 'dLUk2HS4UMoL4j5yHNORNw',
            'x-ig-app-id': '936619743392459',
            'x-ig-www-claim': '0',
            'x-requested-with': 'XMLHttpRequest',
        }

        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            # print(response.headers)
            # print(response.text)
            data = response.json()
            print("Fetched Instagram data.")
        else:
            print(f"Failed to retrieve data. Status code: {response.status_code}")

        media = []
        for node in data['data']['user']['edge_owner_to_timeline_media']['edges']:

            for tn in node['node']['thumbnail_resources']:
                if tn['config_width'] == 480 or tn['config_height'] == 480:
                    thumb = tn['src']

            media.append({"taken_at_timestamp":node['node']['taken_at_timestamp'],"description":node['node']['edge_media_to_caption']['edges'][0]['node']['text'], "thumbnail_src": thumb})

        media.sort(key=lambda x: x['taken_at_timestamp'], reverse=True)

        print(media)

        return media

    except:
        logging.exception("An error occurred scraping Instagram")




from django.conf import settings as user_settings
from . import settings as default_settings

class AppSettings:
    def __getattr__(self, name):
        # If the setting you want is filled by the user, let's use it.
        if hasattr(user_settings, name):
            return getattr(user_settings, name)

        # If the setting you want has a default value, let's use it.
        if hasattr(default_settings, name):
            return getattr(default_settings, name)

        raise AttributeError("'Settings' object has no attribute '%s'" % name)

settings = AppSettings()


import os
from setuptools import setup, find_packages

setup(
    name='django-easy-instagram',
    version='1.0.0',
    description='Instagram client for Django.',
    long_description_content_type='text/markdown',
    long_description=open('README.md', encoding='utf-8').read(),
    author='Tom Anthony',
    author_email='django@tomanthony.co.uk',
    license='BSD-3 License',
    url='https://github.com/TomAnthony/django-easy-instagram/',
    packages=find_packages(),
    platforms='any',
    include_package_data=True,
    install_requires=[
        'requests',
        'sorl-thumbnail',
    ]
)
